@@ -168,6 +168,15 @@ fn main() {
                 .multiple(true)
                 .required(false)
         )
+        .arg(
+            Arg::with_name("cookie")
+                .help("Provide a cookie name and data <name=data>.")
+                .short("-k")
+                .long("--cookie")
+                .takes_value(true)
+                .multiple(true)
+                .required(false)
+        )
         .arg(
             Arg::with_name("debug")
                 .help("Locks application to one thread and displays HTTP response data.")
@@ -222,6 +231,16 @@ fn main() {
         }
     }
 
+    if let Some(cookies) = matches.values_of("cookie") {
+        for cookie in cookies {
+            if cookie.contains("=") {
+                fields.cookies.push(cookie.to_string());
+            } else {
+                eprintln!("cookie is missing `=` separator.");
+            }
+        }
+    }
+
     let url = match matches.value_of("url") {
         Some(s) => s.to_string(),
         None => {
